TODAY(1)

# NAME

today - keep a daily journal


# SYNOPSIS

*today* [[[_YYYY-_]_MM-_]_DD_]++
*today* *grep* _argument_ ...++
*today* *log* [*-v*]++
*today* *-h*


# DESCRIPTION

*today* [[[_YYYY-_]_MM-_]_DD_] opens the journal file for the specified date for
editing by running the command in the $*TODAY_CMD* environment variable. If year
and month are omitted they default to the current year and month. With no
argument a file with the current date is opened for editing.

*today* *grep* _argument_ ... searches through all journal files by calling
*grep*(1) with the supplied _arguments_.

*today* *log* prints the contents of all journal files in reverse chronological
order on standard output. The contents of each file are preceded by the date in
the _YYYY-MM-DD_ format and two newlines and followed by three newlines. If
standard output is connected to a terminal it will be piped to the program
specified in the $*PAGER* environment variable.

Journal files are stored in the directory specified in the $*TODAY_DIR*
environment variable with a _YYYY-MM-DD_ basename and the contents of the
$*TODAY_SUFFIX* environment variable as a suffix.

If a journal file is empty after being edited it's deleted.

Configuration is done through environment variables. This allows keeping
multiple journals by creating aliases or wrapper scripts that set the
appropriate environment variables.


# OPTIONS

*-v*
	Reverse the file ordering in the *log* subcommand, that is print the
	contents of all journal files in chronological order.

*-h*
	Show the program help and version.


# ENVIRONMENT

*TODAY_DIR*
	The directory where journal files are stored. If unset it defaults to
	$*XDG_DATA_HOME/today* if $*XDG_DATA_HOME* is set or
	$*HOME/.local/share/today* otherwise.

*TODAY_SUFFIX*
	The suffix added after the date in journal filenames. Defaults to *.md*
	if unset.

*TODAY_OPEN*
	The command used to pre-process each journal file for *today* *log*.
	It receives the journal file to pre-process as an argument and must
	print the processed data on standard output. Can be used for decrypting
	journal files. Defaults to *cat(1)* if unset or empty.

*TODAY_CMD*
	The command used to edit a journal file. It is passed to *eval*(1). In
	addition to any environment variables, the following variables can be
	used in the command stored in $*TODAY_CMD*:

	- $*TODAY_FILE*    The path to the journal file to be edited.
	- $*TODAY_DIR*     See *TODAY_DIR* above. Contains the default value if unset in the environment.
	- $*TODAY_SUFFIX*  See *TODAY_SUFFIX* above. Contains the default value if unset in the environment.

	The command may be modified to edit any other arbitrary files if
	supported by $*EDITOR*, for example keeping a file with notes that
	persist between days. If unset or empty the following value is used:
	```
	$EDITOR "$TODAY_FILE"
	```

*EDITOR*
	The program used to edit journal files. Defaults to *vi*(1) if unset or
	empty.

*PAGER*
	The program to which the output of *today* *log* is piped. Defaults to
	*more*(1) if unset or empty.


# BUGS

Up-to-date sources can be found at https://sr.ht/~sotirisp/today. Bugs and
patches can be submitted by email to ~sotirisp/today@lists.sr.ht.


# SEE ALSO

*cat*(1), *eval*(1), *grep*(1), *more*(1), *vi*(1)

; SPDX-FileCopyrightText: 2020-2024 Sotiris Papatheodorou
; SPDX-FileCopyrightText: 2024 Ángel Castañeda
; SPDX-License-Identifier: GPL-3.0-or-later
